Package: BIEN
Title: Tools for Accessing the Botanical Information and Ecology
        Network Database
Version: 1.2.6
Authors@R: person("Brian", "Maitner", email = "bmaitner@gmail.com", role = c("aut", "cre"))
Description: Provides Tools for Accessing the Botanical Information and Ecology Network Database.  The BIEN database contains cleaned and standardized botanical data including occurrence, trait, plot and taxonomic data (See <https://bien.nceas.ucsb.edu/bien/> for more Information).  This package provides functions that query the BIEN database by constructing and executing optimized SQL queries.
Depends: R (>= 3.2.1), RPostgreSQL
License: MIT + file LICENSE
Imports: DBI, ape, sf, fasterize, raster, terra, doParallel, parallel,
        foreach
Suggests: knitr, rmarkdown, testthat, maps
VignetteBuilder: knitr
RoxygenNote: 7.2.2
NeedsCompilation: no
Packaged: 2023-01-06 03:04:57 UTC; Brian Maitner
Author: Brian Maitner [aut, cre]
Maintainer: Brian Maitner <bmaitner@gmail.com>
Repository: CRAN
Date/Publication: 2023-01-06 07:50:10 UTC
Built: R 4.2.0; ; 2023-01-11 03:25:25 UTC; unix
