# RBIEN
Tools for accessing the Botanical Information and Ecology Network (BIEN) database

# News:
New license: We've updated the license on the BIEN data to a CC-BY license.  If you are using the Github version of the R package, this change will be reflected when you use the function BIEN_metadata_citation().  A forthcoming publication will also detail this change (and other updates to associated data products and software).

## Installing
To install the development version of BIEN from Github:

```{r}
devtools::install_github("bmaitner/RBIEN")

```

<a href="https://buymeacoffee.com/maitner" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/v2/default-blue.png" alt="Buy Me A Coffee" style="height: 60px !important;width: 217px !important;" ></a>
