% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/internals.R
\name{.native_check}
\alias{.native_check}
\title{Set query details}
\usage{
.native_check(native.status)
}
\description{
Helper function to set query components.
}
\keyword{internal}
