% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/internals.R
\name{.md_check_stem}
\alias{.md_check_stem}
\title{Set query details}
\usage{
.md_check_stem(all.metadata)
}
\description{
Helper function to set query components.
}
\keyword{internal}
